@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: xml-conduit
 version: 1.3.4
-id: xml-conduit-1.3.4-233ad2c214e14cf140bab4070afaa144
-key: xmlco_6FtvMlbWlNYCw4292ieBev
+id: xml-conduit-1.3.4-2cb0835929c2dc7743cd241414dfd06a
+key: xmlco_BdGqZPHhDcSCUAiQROoGJX
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -22,7 +22,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.4
-hs-libraries: HSxml-conduit-1.3.4-6FtvMlbWlNYCw4292ieBev
+hs-libraries: HSxml-conduit-1.3.4-BdGqZPHhDcSCUAiQROoGJX
 depends:
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -31,7 +31,7 @@ depends:
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
+    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
